@@ -1,5 +1,5 @@
 from s3fs import S3FileSystem
-from pandas import read_csv, DataFrame
+from pandas import read_csv
 from pickle import dump as pickle_dump
 from pickle import load as pickle_load
 from psycopg2 import connect as psycopg2_connect
@@ -39,6 +39,12 @@ class S3:
 	def ls(self, path, exclude_empty=False, detail=False, sort_by='path', sort_reverse=True, **kwargs):
 		path = self._get_absolute_path(path)
 		files = self.file_system.ls(path=path, detail=detail, **kwargs)
+
+		# if the path is only a file ls will return itself.
+		if len(files) == 1:
+			if self._root + files[0] == path or files[0] == path:
+				return []
+
 		if exclude_empty:
 			files = [file for file in files if self.get_size(file) > 0]
 		if detail:
@@ -49,6 +55,29 @@ class S3:
 				files.sort()
 		return files
 
+	def tree(self, path, depth_limit=None, indentation='\t'):
+		def _get_tree(_path, _depth):
+			subs = self.ls(_path)
+			if _depth == 0:
+				name = _path
+			else:
+				name = self.get_file_name_and_extension(_path)
+
+			if len(subs) == 0:
+				return f'{indentation * _depth}{name}'
+			else:
+				if depth_limit is None:
+					return f'{indentation * _depth}{name}/\n' + '\n'.join(
+						[_get_tree(_path=sub, _depth=_depth + 1) for sub in subs]
+					)
+				elif depth_limit > _depth:
+					return f'{indentation * _depth}{name}/\n' + '\n'.join(
+						[_get_tree(_path=sub, _depth=_depth + 1) for sub in subs]
+					)
+				else:
+					return f'{indentation * _depth}{name}/\n{indentation * (_depth + 1)}...'
+		print(_get_tree(_path=path, _depth=0))
+
 	def exists(self, path):
 		path = self._get_absolute_path(path)
 		return self.file_system.exists(path=path)
@@ -180,7 +209,7 @@ class S3:
 		:type path: str
 		:rtype: str
 		"""
-		return path.split('/')[-1]
+		return path.strip('/').split('/')[-1]
 
 	@classmethod
 	def get_file_name(cls, path):
@@ -240,7 +269,7 @@ class S3:
 
 		result = None
 		for parquet in parquet_files:
-			data = spark.read.load(parquet)
+			data = spark.read.load(self._get_absolute_path(parquet))
 			if result is None:
 				result = data
 			else:
